@@ -2,6 +2,9 @@
 Module to contain the LinksManager class.
 """
 
+import warnings
+import MySQLdb
+
 from sqlalchemy.engine import create_engine
 from sqlalchemy.orm import mapper, sessionmaker, scoped_session
 from sqlalchemy.schema import Table, Column, MetaData
@@ -71,7 +74,7 @@ class LinksManager(object):
                         max_overflow=-1,
                         pool_timeout=2)
                 try:
-                    from tiddlywebplugins.mysql2 import on_checkout
+                    from tiddlywebplugins.mysql3 import on_checkout
                     from sqlalchemy import event
                     event.listen(ENGINE, 'checkout', on_checkout)
                 except ImportError:
@@ -154,6 +157,8 @@ class LinksManager(object):
         """
         source = _tiddler_key(tiddler)
 
+        warnings.simplefilter('error', MySQLdb.Warning)
+
         try:
             for link, space in set(links):
                 if link is None:
@@ -170,6 +175,9 @@ class LinksManager(object):
                 new_link = SLink(source, target)
                 self.session.add(new_link)
                 self.session.commit()
+        except MySQLdb.Warning, exc:
+            self.session.rollback()
+            pass
         except:
             self.session.rollback()
             raise
